CompositionInterfaceMechanism
=============================

.. automodule:: psyneulink.library.components.mechanisms.processing.compositioninterfacemechanism
   :members:
   :private-members:
   :exclude-members: random
